﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Windows;
using GrapeCity.ActiveReports;
using GrapeCity.ActiveReports.Export.Pdf.Section;
using RtfReport.Data;
using RtfReport.Reports;

namespace RtfReport
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            this.InitializeComponent();
        }

        private List<DocumentReportData> GetReportData()
        {
            List<DocumentReportData> reportDataItems = new List<DocumentReportData>();
            DocumentReportData reportItem = new DocumentReportData("TestDocNr", "TestDocName");
            DocumentPositionReportData prePosition = new DocumentPositionReportData(new DocumentTextPositionReportData(1, @"{\rtf1 Pre-Text}"));new DocumentTextPositionReportData(1, @"{\rtf1 Pre-Text}");
            reportItem.Items.Add(prePosition);
            DocumentTitlePositionReportData titlePosition = new DocumentTitlePositionReportData(2, @"{\rtf1 Title}");
            DocumentPositionReportData textPosition = new DocumentPositionReportData(new DocumentTextPositionReportData(21, @"{\rtf1 Textposition}"));
            titlePosition.Items.Add(textPosition);
            DocumentPositionReportData pricePosition = new DocumentPositionReportData(new DocumentPricePositionReportData(22, @"{\rtf1 PricePosition", 99.50m, 2));
            titlePosition.Items.Add(pricePosition);
            DocumentPositionReportData specialPosition = new DocumentPositionReportData(new DocumentTextPositionReportData(23, this.GetRtfWithImage()));
            titlePosition.Items.Add(specialPosition);
            reportItem.Items.Add(new DocumentPositionReportData(titlePosition));
            reportDataItems.Add(reportItem);
            return reportDataItems;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var dataSource = this.GetReportData();
            DocumentReport report = new DocumentReport(dataSource);
            report.Run();
            this.ShowPdf(report);
        }

        private void ShowPdf(SectionReport report)
        {
            string path = Path.Combine(Path.GetTempPath(), @"RtfReport.pdf");
            PdfExport export = new PdfExport();
            export.Export(report.Document, path);
            Process.Start(path);
        }

        private string GetRtfWithImage()
        {
            return @"{\rtf1\ansi\deff0\nouicompat{\fonttbl{\f0\fnil Calibri;}{\f1\fnil Consolas;}{\f2\fnil\fcharset0 Calibri;}}
{\colortbl ;\red0\green0\blue0;\red0\green0\blue255;}
{\*\generator Riched20 10.0.19041}\viewkind4\uc1 
\pard\f0\fs20\lang2055 Test\par
\cf1\f1\fs19 System.Text.Encoding.UTF8.GetBytes(\cf2 this\cf1 .position.RtfText)\par
\cf0\f2\fs22\lang9{\pict{\*\picprop{\sp{\sn wzDescription}{\sv Image}}{\sp{\sn posv}{\sv 1}}
}\pngblip\picw3334\pich3122\picwgoal1890\pichgoal1770 
89504e470d0a1a0a0000000d494844520000007e0000007608060000000e7027e5000000017352
474200aece1ce90000000467414d410000b18f0bfc6105000000097048597300000ec300000ec3
01c76fa8640000277549444154785eed7d697064d779dde97def4603ddd8970166e5ec0b455143
c91125920a252ab224a76c8b25a59c4a548e2a914b71528e2b7f52a94af9572a958a63a7e2c465
4b8925cbb26469c88814c5e13eb486db50b37330831960b035d0e87d7fdd9d73ee0344daa5d88a
9d601a83fec837ddfdd6fbeef996f37df7be07c74276a98dae6c3b71ae7f76659b4917f86d2a5d
e0b7a97481dfa6d2057e9b4a17f86d2a5de0b7a97481dfa6d2057e9b4a17f86d2a5de0b7a97481
dfa6b26d06695a8d1a1c5cac4a11b9740ace760301af07a5cc0ab20bb7f0ca0bcfc1e376221a0d
c3edf3c3178e213e3c81e4c45ef48cee4228debf7ea6bb43ee6ae0ebc52c6ab934aad934bc0e20
128da058cc23934e23140e2210f0a3b0b682e55b3771e6a5e7e023f0019f1b6e3451a994110a06
e8139dc8e7f218dcb1175347ef4762f711f4edd8bf7e85ad2b771df0eda685727a1ee5d54558d5
0a7173a2d56c21120a231c09612d9346219b432c1685dbe322f0ab98bb7e1d2fd3e2a35406bf97
b0d333e473590c0e0ea15aada15aaba2d56a1b0fd1438f104d243172e403d871ffa3f0f843eb57
de5a72d7c478015e5cbc81954b2fa3b0300dab5686c3e120602d6d854377da6e73bf161cfceda2
4280df5bcd360a8532ea8d16da0e2ff2853a2ebf730bbe501299828554a6623ee716b358e567d9
f2a25eaee1ea73dfc577fef52fe2fab35f37d7da6a7257587c657501c5a59b68b7eaf60a5a67bb
2d789d5c675101da8845a208f8fd48afaed08d57108ff5c0b22c64d732f8f1b97378fdec6bb01a
7558f50686060711094771e9ca15a4522b540a2a55a90a8fd78bc1640f76ee18c150228256bd88
90df8d9e781c933ff7f398fae063f6f5b7806c69e0ad6a0985db376095b3049a564d0b9775b75b
4d03bc83c0b7da4dae6ba1af370eb7cb8595e59401bc2fde8752a984d44a1aa79ff9217ef4e7af
2197c9e2f0e1a398bfcd505116d01eacaea6e1e471352a45a95287d7e940a23782fede1002ee26
86fa09fae810dcce363c89119cfce57f869e911da67d9d2c5bd6d53baa45a4df39875a21a35f8c
e52e3809bcf9cff87529812d8af3921695a3d668709313e57a1d6bd9029e3dfd125e7af5752cae
64114b0e63fad622aedc9847b6544730dc07872b000b1e38dd41780331349d7eac64e5fe9b5848
5771657a118b6b15d4da5c7f73167ff26fbf8c0bcf3f69aed7c9b22581f7d4f2403e452015bf25
eb201bdfc5efb4f68deff202025ecad06c36cd31164341b158c5a9279fc613ffeb69cc2daca2d6
746279b5801bb38bf0877a50aab6506eb491181ee5fe0eb8bc7e2e41345d3ed45b1ecc2eae215f
69c31b19c025827feef22d64ab6d941a2ebcf88dff86d7bffb5535a06365cbb9fa36010fd1ad16
0b052c2d2f507309ac71f1d262c6751138123a7d0af076db82dbed42ac27ca58ddc0fcfc02aa95
269e7eea59fce007cfa252b35021b1f3ba3d3c8ea181bad4b29ac683787d1ec6fb7e72030f9652
29bafa26eab506f76bc023e2d8acc2cd4b87035e92458617869891917e9c38ba17ce560523f71c
c2c7bff46f4cdb3a4d5cbffeaffe4567b6eca748eed63b08ba184b197b6bd52a6374112ee3d6d7
65438509ba7e1856cf18ef70313f0f045023719b63fcfefe53cf18d06b758baebf09ab4d6f40c0
c9f5798c9bc7104d878bbfdbc864d718efcb4cebaaa83303a8546a04d98572a5ca6b703fa75b57
32c797aa16c3470eb96c9a24b18a2cb30c6f630da3871e30cdea24d932aebe307f03d5c29ae96b
49536e9e8089b91ba00c08f6c6b6a3c5edb44c8765c073919c3569cdb51af0d20bafe1ccab6fa1
61096c9776263113e03a9714851ec4e5a107f0c1d572c3e70aa25e5541a70e3733049fb3456b66
4ac8f3a1ed81d574a050b6e8e279ac2780862388dbcb45cccca6d9063f162ebd85cbdffd6dd3ae
4e922d01bc9769532d9f36162c31eedc583585ebd675e1dd75142795a0695239075dbcdcb00be7
cf5fc61b6ffc18e5528dfcce63acdb2c3c4c8bf1148cff0eb3b468d90a1b0d6e6b21e873c3e36c
20e0017cf4ef7e9f8b61c162bec043d8809638449b0a0637d7f850285a58200ff0f9a338fffcf7
70ede9df53b33a463a1e784f93aeb56e174804e27bc17f570c6af63782646f2310561b75ba7727
c1506c7f86eefdf6fca2a9c2c9c29597bb3d3e024b76c085381b901d04bb6555097a8d20b710f0
b11dce3a92111f86e261a6724124e3212a97452743e5a2176853732cc6788b0a63d16b54c91bc8
14307d6316a1481cf94b2f2173f139d3c64e908e06be6dd5e16f940c901b400b78812b6b6bb36b
b5c85c37f669cb0609a216b7d3c7dcdd8f743a876fffe91378ebad0bf078fcdc83de80a7d362a9
7ac778ee2011144974f35c2e860a811d0938e9daeb48845db8f7c04e3c707c3f4e1edd87a37b26
b06762008908d33c307ea870441269b207868d62b54e3e00cc2f6491cf1511ef499060fab1f8dc
d7505d9935f771a7a5a3816fe552045a8013aa9f58bb2cdab66a5b19e46c65c1facddea6b5996d
5cddb4d8f9734bf8f6b7be87d3a75f408580b818bb9b8ccb35b2f32a73f9268f6be9bc5c94ee93
07c24bd30f794908dd6dec9b1cc687df7f14270fefc3a1a951dc333e80bd63097e26b173b40f7d
2117fc249c0e82ef9032f2dae2083478660c4df40f0eb17d6c0bc34da55cc195ef7546bcef58e0
9d8cebce263bd3804d78d9914ab15cec54fb3749165b6fac8cbf9bb45c375332cb6ad1aa7d246f
6da45632f8f6b74fe1873f7c0eb97c89ebc9ecab0d0252372eb9613146f36027e3b7c3adae68c3
ef712140d07ba3414c0c27b17f6a1c137d71c4b8b9d7eb422f63fb6038881d891e1cdbbd030726
4731da1741909cc22d45643b9a3c778de7e6e578adaab98e653590cb65519dbf82f4b91f987bb8
93d291c0abcaeea8e66484145aa4a9bdcbba37aa72cacfeddf1255e4a40002dfc9f4aa582c21b5
bc8aeffcd9f7f0e2cb7f6eeaec4e9797f1de62ecb5cc7e6621406e8f1b6e02ef2261f388b4791c
b867ef4e8c8d0c62e7c4187ac361049815c40341ba7df2027a88209381b0cb81b19e282d7f04fb
27c731da9f848fe7124750007270bbc558a256ea466af51a15d389703484dc5ba7181d2aa6ed77
4a3a12784fb38c569304cbd4dcb566037889c0d622f0b985ff689107e0ff6810587d3e7bfa793c
fbec73ec7c522ce3dedbb4bca6217bfa6e8ee38e0e7e2aa6d39811e63f098299cfaca1522a6271
6901a15008b1708ca032e8eb9a3cb7d7e5869f4d0832240c10c871823e9888731f9e846dd5c89f
490fe94ec2e110afd542b55641301840241246a356c4ea9b77b6acdb71c0cbda3dcd8a01c6fc36
466dc76dc56f3b866bb14137b7a0f5eb8aa07d5f79f9553cfffc0ba640634ec0854e83719d2e57
6c5bca40703468d36a309cd44a88d0da231e0fa2013f3e74fffd78f8918771fcdef761fad62c2e
4d4fa3404ee0a612b4dd6e33c8a3133a751eba7058355e9dde46650136a7b9de1e259aa160948a
e830214a194495e749a7d770e5d9afa37907adbee380f7b4e896d96f02c6c46f5a8e0dbe2d86e4
f1d300cf0e35e073859caaacf9cd37dec237bef14da4d7b2f0f8bcf0d345cbea35b42ae61ea6eb
f6d2254b54ca35eea15643bb52254b8f62e7d83872d92cae4d5f478dc72587475020293cfdd22b
58585d438bcaa27cc24916e8a512f809a8bc0655cbf4a6c8a245cf429ac8f6684ca0425e5187cf
17d0515862082a95abe61ed62e9c36edb813d271c07bc98e4da3d89936f0fa6a4cd97c2a5f6ed3
c536c9e05b8ca36d6a499b3bb569818bf34b86c8a552195a57800038e8de41009a04dbc7b4aa07
bdb128227ec66b9ecfcd38ef631a167234b077b41f87768e606d7e066f9f3d83575f780ecf3efd
142e5db8c8eb3a304405482d2e30bfa7e5d33334d8a41653b436d34527d346ea08f753a1a84105
b3dbd4e0f9532babb6d239dcd4afba190a0e51f97a7b7b917be755735f77423a0a78b706544c4a
4623d6b26eeac6a865e95282f5c562dc14236fca877343369fc71bafbfcedc799131ddcb533003
60ceaece7779bc181a1ac26032c9f84cb7cbeb78987ab949b82254a2a37bc6f1d0078fe1d0ee51
9c3cb61f87778f63a4378263fbf620190b6369f6266281002606fae1637caf2b63c81671757611
0b6b4554e8edbdbe20add869c28008a3dcbecba35a7f818aa192719bac3e8f4030881e2aa0dc5a
2db388f2c255738f9b2d1d05bc6763060d6503f40dab976cb87931724d99b2633dd770c9d0b5cf
cecda14c06af7522721a7b17e9534cf7793d08fabda8147368554b246716c2cc0c0fed99c487ef
3f81a9e1010cf6443036d08bfd3bc77170cf04b24bb328a6e691887a19cb790c434785e9e0ccdc
22deb9b580e9b9255c9bbb8d2bb76e613eb56a46fa3c2e9f5154b55129652ec7b494f750ad329e
13ec785f9f51dc2689ab6e263ff3a67d739b2c1d67f1ea8d0dd025fabee1eaed786fa772f662af
53f56d793985b54c9684ae6e98bde2a9ac8c9b0cf8a914ad737e16b552016e2a588fdf89e3fb77
e0a10f1cc3e4401c21778bacbe8d78d08d44d88be1781853837d98e88f6362b017f190074e7aa3
3512b3eb37e630bf9c83e50e203e3a81d13dbbe18d86512cd7d81629a2bc54dbd4f423117a1d7a
a79a55472416812fa0819d06954137049466cf9b7bdb6ce918e09dec1c173bf6bdd6bd21024e1d
692c9eabe552f5af49e1d8c962cdb76f2f6075658d56c6dcdcebb5eb79540a156b24e9f42ad22b
cba25c981a4be2de43bbe8d6f711603f0127fba65b0efb54bc712049cb4f4482981c1dc4d4e800
867b638806794e0256af92c1335e2b47bf313b87d7de3e87dba925f84241734dd5fcbd0c2dee75
4f258057522b249a1e78e9752c1576c81104baeea9965d42a390366ddc4ce918e015774d67f0fb
c6a2df2ace68b1ffb37f6f58bc71fcec68a547b3b3f374a74ccd184fbd5e3ff754fd9d0b59b88e
93bb0fd0d547023e4c8d0fe2e0de1dccbfa3087a5af01032d5e8797653b26d126037bf4498da05
7d3e5378f1fb7da6aae79515331fef6106a07d12c95ecccddfc6f2ca0a15a3c57d7cbc32c39652
c5169580608bb00419db9dcc22d47e158eccb0f2fa0d9797aff3fbe64ae7583c9aec0c024a33a1
7d9b38a8aed1777592bd8d5d452b36715ba6de16a80e5cbc78053337e70c91e36e8ced16f3663b
1df4d1fa44aea428e57289ca5146b22f8661baf74890403ae9657816d5ed57d65631432bbebdb0
6c3201d5fa038110895b80c085097e80803ae9f603181feac33d3b2750af94d02497c8663226b3
d0ac5e2907392402f420d14888fc234dab4f310435a8085e83b767bdf4ac765552b7ccf7cd94ce
015e6cfe3df26e6c974bb72b735a2740b5dee9b099f25a3a8b57cffc0869e6d82ac9d6e9eab9ab
71c71e87872ed7cd33e85cf401b4dc0463765f22861063adc725d56aa254a96089ee7881a95795
2e3c188d231ceb83cb1be0b6068f23e064ed7e3fc12770f4fa188a077074df24f6ee18c3813dfb
d06aa85cac31790b0d660b0ede8f142c18f42349af3036366a1430cfecc312075123d926dd5323
b76cee7933a5832c5e20bc2b36e8b66cc47889c6ccf55d65509fcf8fb9d9dbb879f396899d7aea
a54ecb951795b234b94eee57c51617ddb4bc89972edbc574cbe5558d5e1e439329a840b99c995a
154ff42312ef3343b5a0e2b4da6e144a75946b2d6e77a34acea0419ce1be08e27e0f26992646a9
10b5aa85a64024e016899c26710c0e26d9d8262accdd35753bb5b464a677974baa4c8a03d0f429
d55cca7c6ea67410f03679db1081bbf17be3bb16c548594a83ae5873e1ce9e7d0d59e6c722759a
27a7411acdb113e8b22c298409a7aaa5cac7d22a1b1a0720206696aed817cfeb647e7e7d66066f
9c7b1b8b4bcb2816cb048fee984b830ab1bc9ac5956b3358584821486f11f2bbc84bea60a42098
695e4b5c841906afa2ca609b9c42eede6ad490600a572c16cdbc3d5512430c1bf6742ffbfeac52
d67c6ea67410f0a6ff8dd8162d4cece6196be7ffeaa82601d6d0abbc40ad52239b9f3339b3d62b
fe0b5c458d960234bfa89a66f1bb46cc1a3ca6629e85233b2798d5860670341f1f88c76318191d
318c5be7d79cfb4cbe6c8a3502fddaf40cae5dbdc16b69a60d50671eee707b4daebeb696e77a5e
530a2a3d6248d1bd68a4578f764901f410a69ece19e81f8247c3c75cafc7b90c5fb9038f60d93d
db114264158d7f02be807773612c6707293797c8aa14d797179718475be88bf7122cafa9ce9101
184b020996091d0e1da314512366a27076f97669258385a534099deaeabc56ab4122e621611be2
f9e2b4e8300e1d3c8691f149e44b3514b954e9cadd4455edc996ab582a5651643e30bf56c0e28a
e603d2d330bcb8d76fc0ed719ac7aee351a6795605518df2457b4c089242cbc3e99e8d176368d8
6ce920e037441d671338894dec081cd3237552a5564386f1f8c9ef3f65e6cf7949c0dcb43cb96a
ee446b93b2d88c41fc49e7721805e2762a4d95642d97296179790db95c0575ba68178f77f33859
7ba2378e5ab988d99b33a8d03defdfb7177b77ef361e6535b346d08ba8f3fc159e3bc3f4f1b5f3
17509452f2783795c7804a25f3d093f4f444e037eb1cf4283df0319dd4f60d17af7bb2f75702b8
b9d231c0abd2e6d05c76e22dd0e50237b6685c5eb15ac44d9d26902cbae96f7ef35b387fe19221
561aa9db50180de06844ee27c08b4881e093ac3508b4705a5dcde3e6ec12f2451242cd93a2357b
09bc97fc60782041965ec6e5f3e7f0a3575ec1ecec2da4d32b28352af0323d8b0d0ca2e1f1e3cd
abd3b8b1bc0207e3b68b39bf9fb9ba88a32e6c031f45ad5e654a1735e796180b977b67fb3694db
21a5dd64e91ce0d9f1a61bd8318cf0ec149bc9ab93948ec93294bee94957c568d5e26766664db5
4e953b298d444a22e079a4ed3cd645f519727b430a35361e0a4550285670f3d63ccaaac6d1fa5c
0cc63eb2fd46b5c43d9b088703cc1cdc0c2d69f4d0134cec9ec2c49e3d7031564fcf2fe3dcd519
34a900853adbc37636ac06e3368963b3ce63fda8d52a460182ccfbd59e77ad5df7637b26a3c877
e019fb8e019edd623e05be5908bc3a45450f3dfa246bcfe70ab872e51d9c397306972e5f4689cc
5bf9709d79b3f66b9041371a4ae73434aaf8a9339a12904e68aa722272ba80e6e5b96869f96201
730b0ba68013601c56eae727502abfb914a799fe45e8a6e3c904a27d099449e66e2eaee06d31fc
d502b2a5aa61fd1532f69a9eae211fd14c9c645f1cb9ec1a7a491a9532164a052a42cdb674354b
cd609bb4b882b1f5359b271d04fcba7912703966e3b2d9490de6cdb9b50ca6e9569f7ff6797ced
0fff074e7df70994f2453311c2c9fd7c04cbcc7055de2eaba332a856cecd0457808b3d574d454d
96b8a29a3dbfabb822ab5b595dc5f55b37912677f045c37072bd3f1683872ebac918ed894650e5
7e258d09a47378f9ec395cbd3e0fa6f6a40dca020820017770511c51f957954895781b568d6165
0599b53594ca25e3d1a4d0baee8647f34613f6bd6fa2748eab374da12d18c0099e66b1b0239d6d
07aa64d1dffdce29fc97dff93dbcf2d2192a420e21923a07dd7aa3ca54a8554324e8251bf7929d
93a8b163c5e23dec78b96a5505b5e8e1c6a8dc6eb3864281b9332fa95a3eb50037e7e6f1e6c58b
b8343387f96c114d5aa145765f68b990a9b7309f2be3f54bd7f1f40b6771617a0185aa1e9c2027
d183966d4db490cef2936dae33cd2cf1fc7dbd3112c43cb2d90cbd49d0ccfe113f51da69979175
e7f410f1417dd954e91c8b6767e8b12506485874dd9a8a2cd7298b5fbcbd88f9b905a83a62d5b8
9d31be54282040573cd01fc3603286a1815ec468cd3eae93b5eb614a33b54a56b89e66d5ab152a
871fa3c3c3267434e91d5cdcc7e70f9298f560315dc2eb17aee1ccdbd7f0da959bb8bc90c1f9d9
653cf7c679bcf0fa05bcf5ce0c16f3e41804dc727ad1629c56ddcf496ea0a77295af0b548fc701
3f197c28126098aa2199ec23c10b332d2c5109b2f410249e0c0f7a804396ef4f4cacf7c2e649c7
00cf6e6347c82d8bcaa91ab684ab8ce3b76edec28fdf3e4fcbae9b818d00c994979fe16080ec3b
89c9f1618c0c25185323548038ad9adb0538438652b0a63c07154af3e23462363e324aafe0473f
6376b954b62d4f01dded87cb1741aedac6955bcbf8e693a7f1b56f7f1f4fbd7816976753c8590e
94087895d9419da0abbd6d8518291a176aad29093bdc6dc4c9e607d936bd4429120922ca505128
e4b1b6b66a14ce76f3bc49b9094a7060a7f9dc4ce9a8e7e363cd1c5d659daebd84179e7f01a9a5
34ae5ebd4ef77e16994c8e9ea06d4a9ec78f1dc191c3f7d0dae3b4f438dd398120c88b4bab78e9
e5b378fbfc252cadae9939f41a3173902bc4e8e28feddf8b5d634358999fc6d4583fd652730873
bda64dd55a6eac966ab8b594c5f5db29a4e8da5b52082a861ed45055ae2c62c6df1a0c52ddc049
02a9a997ca005c622954b21039c1474e1e407fcc85815e2f123d1ee4d20b868b84c2115aff20fc
5e3fc38dcd3d3cb104a67ee9dfadf7c0e649c758bca4ce3c5b565f2103ceacac323e96f999a6bb
a79dd1ba1efed883f897fffc4b5c7e159ffed423b8eff87e8c8df423160db053bd485209068713
e81fec434f5f8ffdb40c2dbf4522e760bc57816566e60653b6009d808a3c5e14c9d01a0e3faa2d
0f32c53a1648de96334568ca67836ebbc1769171105a72738267cab26ca343ae9de70fd0fbe809
1a077949c0e7c4d48e010c2642f03a2d3303c7d29334b4f2304963b23f8140c067ce260fa1b182
f0f811fbe637593a0af886837193315e2f31387ee2383bac82ebd3d346193efff9c7f195af7c19
efbfff0442411fdd373b96966e62b4cfc77d94133b914a2d9b9719ace708365924dbd7bbea6666
6e6139b5620a268da646d2c8d4ab4d9468c17912b2144963364fe64d02a6ba8246eae9308c02d5
c907cca3d3fceda307d0740b4dbc149ff07209b32d07f74ee1183d51845e44b3757c1e5a3bb94a
34124382a9a0266528e68bc9ab9a27971f9e3cbaded0cd958e02de72b8d1e4a267cdd4291acd1a
9f18c5b1e347f1d9cf7e8a007bcceb49d4694a8936523ed5f2bd5e1f2d3f669446439fa54291ee
b4691e9a5065dc4b6e90c9e65021c81a6f67d420d80d734dbdeb2647ef92cee4912b554ca188c6
6816958b956cb8943a4a9b784e1fddbdf8828b19478be4d3cd1d93f128eed9338958d04d525ae2
15d5367b20a637de6bda6a8688a9507ad246e7129b0f0eedb16f7e93a5a38097d49c7e685ebaaa
601576601f5df617bef03822d120d7eb8148769c5b8b98b38f0b993c41777bbc4c97223871fc04
060686cc18b8264db868b5d16814870e1dc2f88e29144a5503f6be43c731be730f128363a8d1f2
f3248f65c668016ca7965a888e081bdba3ba3a23beb17af3d815417712c800ad5eaf4b1de8d57c
7d7a90fc2add7bc558bbb8ca40b2df288928abfe9322ea535a15ddf301ddf21d918e7b074e8b8c
d9515ec3f4b57770f1e2653cfaf1c7b073d72e9237b161c1c178cac51e6d931b67f4a51569468e
c6e303c110768c4f999714653219b2ea084698be8d8e8e629c8b5e9a74f9d265c65c660164f887
a82813933be9f61da835e8ca19fff5a932b0e6c699295c044b15c116ad5d4a278560f431052105
8480bf8dc307a608701d85dc0a330fcdc8d55b345c88c7c2f446caddc50d789c692b8f63b818fe
e817d964bb86bfd9d2812f3f22a08cf337ae5ea4a5f6e0830f7c48464788351152e3f1750338bd
b029bea823890ff4f084f263d5ec0364fe63a3630c13e3181e19c6bdefbb97969744219f436f4f
dc9c6ffac675b80948888a11eded356c7b747c82eb025006e822308562d1ccf7136072dbe60919
b6cf7ecb96aa7574f32e0b3b27869852f6a24285f57a68c9e1305a24743dd110d34e2fcac50239
46cd3c4c211151ed3df43042e387cdef3b211de7ea8d84126620e6d0c1c388f5c4e0f36bb0c46f
0a251afdd2234c7a0e4e80b7186f1d74f3f4be061481e4f5b9cdecd74387f6e3e8918364fc7e44
6979bb764d616ad7241ef8e003e8edebc5fcc23ce61717cc3cb882de7249e2b7387f1bf58a66df
b0190c232e9e4f71da2824afa999bb4daa5ddb21eb6fa32fd183a9a9318615ba715a7522de6308
9f4ab57a3b7691a06b22a6eaf42275a672c774aef7e8a3f6bdde21e94ce069c5073ff011f3d893
9e8a11bfd2240b8daad90517ed42d2c6f80ac66bed23e66d46d8c8f2a5203ebf8b39bf8bdc2060
c6c5057e381c34047160208943870f5219a2b8face55a4d3690374a190c3cd99eb585d5936e0bb
791e0fafa3786c068dec286fbeab4ceb24e7d0342c9fd7496b271fe921e8ec5255153568a48666
32592aa20f8944c228ab868bfb4efc3d38e959eea47426f094fe1d7be18e68c68a5ca3db8ca4a9
d3151bb5e8a10937499d94c454cc889c793a36e8370f2f28e4cbf22311156854be75d0d5920c12
282773e870c8cff81b31132f52a925e805c683c904764e4e321cf0ba04ae56a91073ba7822e856
2ca682d98f6cb129045edbaae5bc99b8a18aa14724a4d9467a6d8d24d48d7c216f6af47d3cafc0
97628647ef41ef818f9a7bbc93d2b1c04b5c4c77c4a69552e959331a9ab11a59ba66cd68c05538
0874e5471a8757aaa77c59a4cc4180c5fef5dbc904bcd5666eedd7bcf6b629aa282bd839b5c3c4
60cd8dd3b4abe3c78e9a5937c9441fcfc5e0c1c566145af4c1758c2b9a66d5b2da18ea4f184bd7
831762fa9562c93cb8a1b45215bf24b985bc94da2f77df7fdf2fd8e7b9c3d2d1c0b76965157f98
164eb095661925904be736753eaddd43057039b98db8689deec8a311390f77324a424ba7db0f04
bc66b44e39b48b1c21b5b2625c7d2f63728499800683f450a45e61ba6fdf6ef28303d8b993d64f
e2a7b82cf8955958cd2a954a64cfcc19a29750bac670c46dcd5683dbeba660e376fb4c8cf7f0d3
9ec0d9c0c0039f4330b9f903323f4d3a1a7889c558d80c460824c1a415abb0f36ef146b1979088
035009945ce9b78032564eeb975fd663cbcaf7fdc100d3350f8a74e19a923da2011b6600415aa7
510aea8af9bb349110b70d520906b07bf76ef4f5d1fa757ec3e6d9260dbe04dd64ef3cafe6e6d3
d3789821942b25736df33a16c6f25088ec9edbea9a7eb5efc3183d716709dd7ba5e38197686cbc
e90998dcd9e4c224595200130268795c6b80374a417760c28199da64a77b7af7ac14419941301c
62ac0fe0c0e143fc1ec66a7ad5fc01a2fefe3e9bcc117859b0c6f59716974cf14573e63c4efba9
1c956bcd902f9564c7c4b02928893f2805151fd120d2eaeaaae1180a379ae61d9e3c81dd1ffbc7
f6cd74886c09e025cd709cbd4a0b22c8766c57290768b063cd64265ab7e6c88b049af977029c9f
024b1e41ca2172e5612a15632c1f1e1f45ae54e0f71e5316f679a54c24925c64f1112a483c1a45
8e44ad9c2f9809211e2913cfa57d549f3f74700f491d89a446e5c52fa8948d864ac84cf5f85d61
253a7904fb3efdeb6a4047c996015ed28c31250ae96d1204536ed7903a5b0154cc110f10056b72
51dc17b99218cbe7a2fc5f2cdb47d72ef0078787911820e30eb8490c1bf0d27a4508b58468f1e3
23c358595a32f15f51432f2f56454ef9452cea63da96611a97653469a05eab9a099c7abb752c16
23aff0a167d771eced40d0255b0a78492bd207047b0c98268f272202ddc3d44ef3e765e95a6f1e
b2e0a7ed19ec344c6e5f8ae227f08af73ace3caecc7368b68e74495535cdd611d1db39396efea4
49db8ccc35b9be05867478dd2d0c247ab84e133beb2832ffaf9237581a5c32b50627eef9c867b0
eb135f5c6f75e7c996035ed20c46d18ef4dae073919867ead641577c37a369520c82aef52ab7da
b1dff60c7a0843448c2bb85de6aced76fa46ce4e8fd1420ff3fc7bf6eee2679831df656aef6ea7
454f904434e433bffd248e8d6ad54ccb16f01a257ce81ffd06f63ffa05d3ae4e95adfd57a86889
8d4c1aadf5bf2f67d22e7337247d64d6255a62be9817ee76ec37a45000354ccd5f4bb552602a56
a5e69039582d9ed2825597bb672a59a963666e01b942196fbcf5166e5e9f66ae1fc29103bb10f0
5ae8ef0920e0d1fb77565129553079e47e7ce8f17f8af816f8634477c59f1fb30a79b44a7943e6
cc0318b26092be72a9883cc1570146f15eee5e16dfa2650a74a565956a097a08c24c8de6b17ac9
8194c64caa62c650aad6b1ba96c5333f3c8d95c5db387ee40006fac270b56be6cf8ff8c9e835b1
63df473f83238f744671e66791bb027823028d40d77359f3b89200d46b490b5408f36a13022fb6
2fe09516aae0d2685451ab3336eb210c32710795c59e9b4fabd7ec28ba8a52ad8132c9ddd52bd7
502fe73098ec652a5146ab514226bd8c138f7c1af73ef6397898c66d25b97b805f17f387882a65
340a0594736b6632876aea36f92399d35ba968cfb272cd8215f87a12471e423977cbaa9939fdf6
1468fb8f0e90cb9bb9fd75a67f56bd045fc88f917d8731f5be9f6346b035ffc4e85d07fc7bc5a2
0294c9012ad955c3d47dc1b071f7e675e5045b237035ba7ae5e01a5b57ec6fd4343043735f2fc9
ea7d3aeaa060388e7072103d2363880e8ed817d8c2725703ff5ed1a35572e58ae5fa2e425825f1
2b17b2c62b58b47c790b0da688f5fb0264f2911e78c23104e3ccf5a93477936c1be0bbf217654b
e6f15df9db4b17f86d2a5de0b7a97481dfa6d2051ed378f2b74ef1dfbf46d23fc2d77e96fdb688
7481ff59a5effdf8fc6f7e12bbd67f026b38fb5fff106737ffc5d3ff4fa40bfc3695cecee3e55e
ff1478e8e3c0d93f3b8b9b050baec8244efefdc7703cb682b3df3b85b3d74b683adde83df8303e
f5e83e44dfabcaad1cae3ef37d9cb9b0887c1d7005fa3179f22378e8be21f337696c91abbf8c5d
5f3e88c5af3f81b757f4ce3a1f92871fc5cf3f3c89e0c6f9d6dbf2892fbe1fbd3f2d3cf49dc4e7
cd36a07ced0c9e79e51ce6166bf6a4105e77df238fe1a1fd9bff92a3ff93743ef05f7d03187a3f
feee674e20e9b5903ff704fee8b92afae335444ffe021edc1382ab9ec2d93ffe16de4c7c12bffa
e8987d6c8baef80ffe272e26a9101fdb875e2fd0cccde18d274fe1cdc023f8954fef5a075f20be
88d4e4104e7ef461ec4dbad12ccce1cc9f7c0bd3938fe3571eec377bfd45e02572f5a780cffe03
dcd76756bc2b2b33986e0d6372400f535ba82d5fc1535f7f11a14f7d090f4daeef7387a5f35d7d
7d18f719d0f5c38de8d1c7f0a19145a4471ec143025dabbdfdb8efe32710ba3e8345fda694cf9d
c69bb187f1b94fdaa04b5cb131dcf74b9fc681c51771f62fbd297cd7838f1ad025aec8183ef4b1
13b0ae4e13debf812427b1cb802e71c33770100f7f907ee2ca9c59d309d2f9c0c787d641df1076
a407181eb1ff58ef4fa4af0fbd851c4aeb3f176ecd61ecd0bef7b8f475710ee1c041e0e6f47b21
4d626860fdeb868c0c633893fe1b01df5c7e1b4ffec1efe0b77feb3fe03f6af9f7bf8f272e6840
a8b6bec79d97ad4bee6ce3ec3ca95fc1135fbd80e8df791cffe437be825ffb4d2ebff6381e3b6a
07884e91ad0bfc5f23c323fd983b7f457fddfd2f4a6b11172f003b76fd7f02e2e635dc9c3c8193
93313309d808c9a2627d27c95d0b7cf0de47713cf70cfee8d415ac54ed4e17693bfb8d53b832f1
204efe65d7fe7f2d51847ad670f57cca30f7a6fe8ead64641c63336fe0cc0cb30dfd6e59587be7
349e7c71f3ff0ac55f25772df070f6e2be2f7c0127bde7f0c47ffe4f26d6feee7f7f11f9c3bf88
7ff889c975e2f5b711370e3cf811442ffcb189e5bffb8d8bc86b75e8083ef1cbbbb0f6fddfb763
3ce3fb0f6786f1d043ebd9468748773c7e9bcadd6bf15df92ba50bfc36952ef0db54bac06f53e9
02bf4da50bfc36952ef0db54bac06f53e902bf4da50bfc36952ef0db54bac06f53e902bf4da50b
fc36952ef0db54bac06f53e902bf4da50bfc36952ef0db54bac06f53e902bf4da50bfc36952ef0
db54bac06f4b01fe3797aba9e1963a00da0000000049454e44ae426082
}\f0\fs20\lang2055\par
}";
        }
    }
}
